==> dl.php?src=linea21_2_3_0.zip: linea21/languages/es/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "panel de indicadores";


/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "valor";
$lang['dashboard']['name_pluriel'] = "valor(es)";
$lang['dashboard']['confirm_add'] = "Valor añadido correctamente";
$lang['dashboard']['confirm_mod'] = "Valor actualizado correctamente";
$lang['dashboard']['confirm_sup'] = "Valor eliminado correctamente";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Panel de indicadores";

$lang['dashboard']['h1_public_comment']="El panel de indicadores representa el estado de su municipio en cuanto a desarrollo sostenible (filtrado por escala).<br />";
$lang['dashboard']['h1_public_comment_anim']="El panel de indicadores representa el estado de su municipio en cuanto a desarrollo sostenible.<br />";

$lang['dashboard']['mode_aff']="Modo de vista";
$lang['dashboard']['mode_by_project']="Vista de proyecto";
$lang['dashboard']['mode_by_finality']="Vista de finalidad";
$lang['dashboard']['mode_aff_info']="Información global";
$lang['dashboard']['mode_aff_evaluation']="Criterios de evaluación";
$lang['dashboard']['mode_aff_provider']="Proveedor";
$lang['dashboard']['mode_aff_rules']="Reglas";
$lang['sdi']['goal_public']="Objetivo público";
$lang['sdi']['consulting_public']="Propuestas de mejora para este indicador";
$lang['dashboard']['associated_projects']='Proyecto(s) asociado(s)';

$lang['dashboard']['tab-attached']='Indicadores estratégicos';
$lang['dashboard']['tab-not-attached']='Indicadores comunes';
$lang['dashboard']['tab-all']='Todos';

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Valores de indicadores relacionados con  %s";
$lang['dashboard']['graphic_value']="valor gráfico";
$lang['dashboard']['numeric_value']="valor numérico";
$lang['dashboard']['tendencies_value']="tendencia";
$lang['dashboard']['label_value']="etiqueta del indicador";

$lang['dashboard']['multivalue_label']="etiqueta";
$lang['dashboard']['multivalue_value']="valor";
$lang['dashboard']['multivalue_distribution']="distribución";
$lang['dashboard']['multivalue_total']="total"; 
$lang['dashboard']['global_rate']="Evolución global";
$lang['dashboard']['cagr']="<abbr title=\"Tasa de Crecimiento Anual Medio\">CAGR</abbr>";

$lang['dashboard']['to_detail_chart']="Ver la repartición";
$lang['dashboard']['negative_values_notice']="[valores negatives no mostrados]";

$lang['dashboard']['evaluation_values_summary']="Valor de los criterios de evaluación para el indicador actual";
$lang['dashboard']['all_values_summary']="Tabla de valores para el indicador actual";

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Añadir un nuevo " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Crear un informe";
$lang['dashboard']['mod'] = "Editar valor";
$lang['dashboard']['sup'] = "Eliminar " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Valores del indicador";
$lang['dashboard']['list'] = "Panel de indicadores ";

$lang['dashboard']['embed_png_chart'] = "<strong>Usted puede insertar este gráfico dinámicamente desde una página o aplicación externa.</strong><br />Para realizarlo, solo copie el URL al hacer clic en el botón<br/><span class=\"param\">Imagen con anchura y altura(en píxeles) pueden ser modificados cambiando los parámetros <kbd>w/</kbd> y <kbd>h/</kbd> en el URL.</span>";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Añadir un nuevo " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "sin comentario";
$lang['dashboard']['confirmation'] = "confirmar registro";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "¿Está seguro de que desea eliminar el " . $lang['dashboard']['name'] . " ?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "valor del indicador";
$lang['dashboard']['threshold_value']="umbral";
$lang['dashboard']['historic'] = "Balance del indicador";
$lang['dashboard']['rep_graph'] = "Vista gráfica del indicador";
$lang['dashboard']['sdi_info'] = "Nombre del indicador";
$lang['dashboard']['scale'] = "escala asociada";
$lang['dashboard']['date'] = "fecha de publicación";
$lang['dashboard']['day'] = "día";
$lang['dashboard']['month'] = "mes";
$lang['dashboard']['year'] = "año";
$lang['dashboard']['rate'] = "porcentaje";
$lang['dashboard']['comment'] = "comentario";
$lang['dashboard']['comment_status'] = "estado del comentario";
$lang['dashboard']['public'] = "público";
$lang['dashboard']['private'] = "privado";
$lang['dashboard']['previous_value'] = "valor previo : %s";

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " últimos valores agregados ";
$lang['dashboard']['qb_mod_title'] = " últimos valores modificados ";


/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Seleccionar de la lista --";
$lang['dashboard']['facultatif'] = "opcional";
$lang['dashboard']['aff_dashboard_e'] = "Mostrar criterios de evaluación";
$lang['dashboard']['aff_dashboard_r'] = "Mostrar reglas de referencia";
$lang['dashboard']['aff_dashboard_p'] = "Mostrar dirección del proveedor";
$lang['dashboard']['novalue'] = "Valor no disponible";
$lang['dashboard']['value_tendance'] = "Tendencia general del indicador";
$lang['dashboard']['tendance_asc'] = "ascendente";
$lang['dashboard']['tendance_desc'] = "descendente";
$lang['dashboard']['all_value'] = "Todos los valores del indicador";
$lang['dashboard']['barre'] = "Estado del indicador respecto al valor umbral";
$lang['dashboard']['global_value'] = "valor total";
$lang['dashboard']['det_sdi'] = "Mas información sobre este indicador";
$lang['dashboard']['det_sdi2'] = "Información general";
$lang['dashboard']['download_chart'] = "descargar gráfica";
$lang['dashboard']['session-stored']="%s indicators are stored in session";
$lang['dashboard']['last_year_reference']="Último año de referencia: %s";

/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "Se requiere un valor numérico para el indicador";
$lang['dashboard']['object_notgoodvalue'] = "El valor debe estar dentro del rango de medida";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "Para añadir un nuevo indicador, inserte la información requerida en el formulario.";
$lang['dashboard']['help_add2'] = "Para visualizar el valor mínimo, máximo, umbral y frecuencia de recogida del indicador actual, haga clic en 'información de medida'.";
$lang['dashboard']['help_add3'] = "Para visualizar todos los valores del indicador en la escala actual, haga clic en '" . $lang['dashboard']['all_value']."'";
$lang['dashboard']['help_add4'] = "Para editar todos los valores del indicador en la escala actual, haga clic en 'revisar valores'.";
$lang['dashboard']['help_add5'] = "Introduzca un valor numérico comprendido entre los valores mínimo y máximo del indicador actual.";
$lang['dashboard']['help_add6'] = "Los campos con asterisco son obligatorios";


$lang['dashboard']['help_list1'] = "Para visualizar los pares de valores escala/indicador, haga clic en la etiqueta del indicador.";
$lang['dashboard']['help_list2'] = "Para añadir un nuevo par de valores escala/indicador, haga clic en el icono 'añadir nuevo indicador'.";
$lang['dashboard']['help_list3'] = "Puede seleccionar diferentes escalas para visualizar el panel de indicadores : los indicadores correspondientes a la escala seleccionada aparecerán en el panel.";
$lang['dashboard']['help_list4'] = "Para una escala seleccionada, cada indicador tienen asociada una barra en el panel de indicadores. Si la flecha esta a la izquierda del valor umbral (centro de la barra), el último valor registrado para ese indicador supera el valor umbral";
$lang['dashboard']['help_list5'] = "Para más de dos valores, aparecerá un icono de tendencia junto al contador visual.";
$lang['dashboard']['help_list6'] = "El último valor del par indicador/escala aparece junto al contador visual. ";
$lang['dashboard']['help_list7'] = "En la cabecera de la página aparece una barra explicativa, que representa el estado general de los indicadores en la escala seleccionada.";
$lang['dashboard']['help_list8'] = "Recomendación: Dejando el cursor sobre los elementos de la página puede visualizarse la información de las diferentes herramientas.";


$lang['dashboard']['help_mod1'] = "Para editar los contenidos, inserte la información requerida en el formulario. ";
$lang['dashboard']['help_mod2'] = "Para visualizar el valor mínimo, máximo, umbral y frecuencia de recogida del indicador actual, haga clic en 'información de medida'.";
$lang['dashboard']['help_mod3'] = "Para visualizar todos los valores del indicador en la escala actual, haga clic en '".$lang['dashboard']['all_value']."'";
$lang['dashboard']['help_mod4'] = "Si el resumen no le permite modificar valores, haga clic en 'revisar valores'";
$lang['dashboard']['help_mod5'] = "Introduzca los valores mínimo y máximo del indicador actual";
$lang['dashboard']['help_mod6'] = "Los campos con asterisco son obligatorios";


$lang['dashboard']['help_rap1'] = "El informe se publica en formato PDF o Word, legible con Acrobat Reader, Microsoft Office o LibreOffice.";
$lang['dashboard']['help_rap2'] = "Seleccione las opciones que desea incluir en el informe a publicar.";
$lang['dashboard']['help_rap3'] = "Para abortar el proceso de publicación, haga clic en 'cancelar'.";


$lang['dashboard']['help_det2'] = "Para añadir un nuevo par de valores escala/indicador, haga clic en el icono 'añadir un nuevo valor'.";
$lang['dashboard']['help_det3'] = "Para editar un par de valores escala/indicador, haga clic en el icono 'editar valor'.";
$lang['dashboard']['help_det4'] = "Para eliminar un par de valores escala/indicador, haga clic en el icono 'eliminar valor'.";
$lang['dashboard']['help_det1'] = "Preste atención a la asociación valor-indicador, y también a la escala.";
$lang['dashboard']['help_det5'] = "Para visualizar más información sobre el indicador, su proveedor, reglas de referencia y criterios de evaluación, haga clic en 'mostrar información'.";


$lang['dashboard']['help_sup1'] = "Para eliminar un valor permanetemente, haga clic en 'eliminar valor'.";
$lang['dashboard']['help_sup2'] = "Si desea unicamente deshabilitar un valor, cambie al estado 'borrador'.";
?>

==> dl.php?src=linea21_2_5_0.zip: linea21/languages/es/lang_dashboard.utf-8.php <==
<?php
/**
 * @package linea21\languages\es
 * @author $Author$ - Raul Agraz, Marta Rada Arias, Alejandro Villar Fernández (www.icane.es) & linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['dashboard']['section'] = "panel de indicadores";


/*	nommage des modules
 *  	*/
$lang['dashboard']['name'] = "valor";
$lang['dashboard']['name_pluriel'] = "valor(es)";
$lang['dashboard']['confirm_add'] = "Valor añadido correctamente";
$lang['dashboard']['confirm_mod'] = "Valor actualizado correctamente";
$lang['dashboard']['confirm_sup'] = "Valor eliminado correctamente";




/*	nommage public
 *  	*/
$lang['dashboard']['list_public']="Panel de indicadores";

$lang['dashboard']['h1_public_comment']="El panel de indicadores representa el estado de su municipio en cuanto a desarrollo sostenible (filtrado por escala).<br />";
$lang['dashboard']['h1_public_comment_anim']="El panel de indicadores representa el estado de su municipio en cuanto a desarrollo sostenible.<br />";

$lang['dashboard']['mode_aff']="Modo de vista";
$lang['dashboard']['mode_by_project']="Vista de proyecto";
$lang['dashboard']['mode_by_finality']="Vista de finalidad";
$lang['dashboard']['mode_aff_info']="Información global";
$lang['dashboard']['mode_aff_evaluation']="Criterios de evaluación";
$lang['dashboard']['mode_aff_provider']="Proveedor";
$lang['dashboard']['mode_aff_rules']="Reglas";
$lang['sdi']['goal_public']="Objetivo público";
$lang['sdi']['consulting_public']="Propuestas de mejora para este indicador";
$lang['dashboard']['associated_projects']='Proyecto(s) asociado(s)';

$lang['dashboard']['tab-attached']='Indicadores estratégicos';
$lang['dashboard']['tab-not-attached']='Indicadores comunes';
$lang['dashboard']['tab-all']='Todos';

/* informations affichages tableau
 * */
$lang['dashboard']['list_public_summary']="Valores de indicadores relacionados con  %s";
$lang['dashboard']['graphic_value']="valor gráfico";
$lang['dashboard']['numeric_value']="valor numérico";
$lang['dashboard']['tendencies_value']="tendencia";
$lang['dashboard']['label_value']="etiqueta del indicador";

$lang['dashboard']['multivalue_label']="etiqueta";
$lang['dashboard']['multivalue_value']="valor";
$lang['dashboard']['multivalue_distribution']="distribución";
$lang['dashboard']['multivalue_total']="total"; 
$lang['dashboard']['global_rate']="Evolución global";
$lang['dashboard']['cagr']="<abbr title=\"Tasa de Crecimiento Anual Medio\">CAGR</abbr>";

$lang['dashboard']['to_detail_chart']="Ver la repartición";
$lang['dashboard']['negative_values_notice']="[valores negatives no mostrados]";

$lang['dashboard']['evaluation_values_summary']="Valor de los criterios de evaluación para el indicador actual";
$lang['dashboard']['all_values_summary']="Tabla de valores para el indicador actual";

/*	nommage rubrique module
 *  	*/
$lang['dashboard']['add'] = "Añadir un nuevo " . $lang['dashboard']['name'];
$lang['dashboard']['rap'] = "Crear un informe";
$lang['dashboard']['mod'] = "Editar valor";
$lang['dashboard']['sup'] = "Eliminar " . $lang['dashboard']['name'];
$lang['dashboard']['det'] = "Valores del indicador";
$lang['dashboard']['list'] = "Panel de indicadores ";

$lang['dashboard']['embed_chart'] = "<strong>Usted puede insertar este gráfico dinámicamente desde una página o aplicación externa.</strong><br />Para realizarlo, solo copie el URL / iframe al hacer clic en el botón<br/><span class=\"param\">Imagen con anchura y altura(en píxeles) pueden ser modificados cambiando los parámetros <kbd>w/</kbd> y <kbd>h/</kbd> en el URL  o <kbd>width</kbd> y <kbd>height</kbd> en el iframe.</span>";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['dashboard']['add_title1'] = "Añadir un nuevo " . $lang['dashboard']['name'];
$lang['dashboard']['recap_commment'] = "sin comentario";
$lang['dashboard']['confirmation'] = "confirmar registro";


/*	nommage rubrique sup
 *  	*/
$lang['dashboard']['sup_value_warning'] = "¿Está seguro de que desea eliminar el " . $lang['dashboard']['name'] . " ?";


/*	nommage élément rubrique

*  	*/
$lang['dashboard']['value'] = "valor del indicador";
$lang['dashboard']['threshold_value']="umbral";
$lang['dashboard']['historic'] = "Balance del indicador";
$lang['dashboard']['rep_graph'] = "Vista gráfica del indicador";
$lang['dashboard']['sdi_info'] = "Nombre del indicador";
$lang['dashboard']['scale'] = "escala asociada";
$lang['dashboard']['date'] = "fecha de publicación";
$lang['dashboard']['day'] = "día";
$lang['dashboard']['month'] = "mes";
$lang['dashboard']['year'] = "año";
$lang['dashboard']['rate'] = "porcentaje";
$lang['dashboard']['comment'] = "comentario";
$lang['dashboard']['comment_status'] = "estado del comentario";
$lang['dashboard']['public'] = "público";
$lang['dashboard']['private'] = "privado";
$lang['dashboard']['previous_value'] = "valor previo : %s";

/*	nommage quickbox
 *  	*/
$lang['dashboard']['qb_add_title'] = " últimos valores agregados ";
$lang['dashboard']['qb_mod_title'] = " últimos valores modificados ";


/*	divers
 *  	*/
$lang['dashboard']['select_choice'] = "-- Seleccionar de la lista --";
$lang['dashboard']['facultatif'] = "opcional";
$lang['dashboard']['aff_dashboard_e'] = "Mostrar criterios de evaluación";
$lang['dashboard']['aff_dashboard_r'] = "Mostrar reglas de referencia";
$lang['dashboard']['aff_dashboard_p'] = "Mostrar dirección del proveedor";
$lang['dashboard']['novalue'] = "Valor no disponible";
$lang['dashboard']['value_tendance'] = "Tendencia general del indicador";
$lang['dashboard']['tendance_asc'] = "ascendente";
$lang['dashboard']['tendance_desc'] = "descendente";
$lang['dashboard']['all_value'] = "Todos los valores del indicador";
$lang['dashboard']['barre'] = "Estado del indicador respecto al valor umbral";
$lang['dashboard']['global_value'] = "valor total";
$lang['dashboard']['det_sdi'] = "Mas información sobre este indicador";
$lang['dashboard']['det_sdi2'] = "Información general";
$lang['dashboard']['download_chart'] = "descargar gráfica";
$lang['dashboard']['session-stored']="%s indicators are stored in session";
$lang['dashboard']['last_year_reference']="Último año de referencia: %s";

/*	messages
 *  	*/


$lang['dashboard']['object_notvalue'] = "Se requiere un valor numérico para el indicador";
$lang['dashboard']['object_notgoodvalue'] = "El valor debe estar dentro del rango de medida";


/*	rubrique d'aide
 *  	*/
$lang['dashboard']['help_add1'] = "Para añadir un nuevo indicador, inserte la información requerida en el formulario.";
$lang['dashboard']['help_add2'] = "Para visualizar el valor mínimo, máximo, umbral y frecuencia de recogida del indicador actual, haga clic en 'información de medida'.";
$lang['dashboard']['help_add3'] = "Para visualizar todos los valores del indicador en la escala actual, haga clic en '" . $lang['dashboard']['all_value']."'";
$lang['dashboard']['help_add4'] = "Para editar todos los valores del indicador en la escala actual, haga clic en 'revisar valores'.";
$lang['dashboard']['help_add5'] = "Introduzca un valor numérico comprendido entre los valores mínimo y máximo del indicador actual.";
$lang['dashboard']['help_add6'] = "Los campos con asterisco son obligatorios";


$lang['dashboard']['help_list1'] = "Para visualizar los pares de valores escala/indicador, haga clic en la etiqueta del indicador.";
$lang['dashboard']['help_list2'] = "Para añadir un nuevo par de valores escala/indicador, haga clic en el icono 'añadir nuevo indicador'.";
$lang['dashboard']['help_list3'] = "Puede seleccionar diferentes escalas para visualizar el panel de indicadores : los indicadores correspondientes a la escala seleccionada aparecerán en el panel.";
$lang['dashboard']['help_list4'] = "Para una escala seleccionada, cada indicador tienen asociada una barra en el panel de indicadores. Si la flecha esta a la izquierda del valor umbral (centro de la barra), el último valor registrado para ese indicador supera el valor umbral";
$lang['dashboard']['help_list5'] = "Para más de dos valores, aparecerá un icono de tendencia junto al contador visual.";
$lang['dashboard']['help_list6'] = "El último valor del par indicador/escala aparece junto al contador visual. ";
$lang['dashboard']['help_list7'] = "En la cabecera de la página aparece una barra explicativa, que representa el estado general de los indicadores en la escala seleccionada.";
$lang['dashboard']['help_list8'] = "Recomendación: Dejando el cursor sobre los elementos de la página puede visualizarse la información de las diferentes herramientas.";


$lang['dashboard']['help_mod1'] = "Para editar los contenidos, inserte la información requerida en el formulario. ";
$lang['dashboard']['help_mod2'] = "Para visualizar el valor mínimo, máximo, umbral y frecuencia de recogida del indicador actual, haga clic en 'información de medida'.";
$lang['dashboard']['help_mod3'] = "Para visualizar todos los valores del indicador en la escala actual, haga clic en '".$lang['dashboard']['all_value']."'";
$lang['dashboard']['help_mod4'] = "Si el resumen no le permite modificar valores, haga clic en 'revisar valores'";
$lang['dashboard']['help_mod5'] = "Introduzca los valores mínimo y máximo del indicador actual";
$lang['dashboard']['help_mod6'] = "Los campos con asterisco son obligatorios";


$lang['dashboard']['help_rap1'] = "El informe se publica en formato PDF o Word, legible con Acrobat Reader, Microsoft Office o LibreOffice.";
$lang['dashboard']['help_rap2'] = "Seleccione las opciones que desea incluir en el informe a publicar.";
$lang['dashboard']['help_rap3'] = "Para abortar el proceso de publicación, haga clic en 'cancelar'.";


$lang['dashboard']['help_det2'] = "Para añadir un nuevo par de valores escala/indicador, haga clic en el icono 'añadir un nuevo valor'.";
$lang['dashboard']['help_det3'] = "Para editar un par de valores escala/indicador, haga clic en el icono 'editar valor'.";
$lang['dashboard']['help_det4'] = "Para eliminar un par de valores escala/indicador, haga clic en el icono 'eliminar valor'.";
$lang['dashboard']['help_det1'] = "Preste atención a la asociación valor-indicador, y también a la escala.";
$lang['dashboard']['help_det5'] = "Para visualizar más información sobre el indicador, su proveedor, reglas de referencia y criterios de evaluación, haga clic en 'mostrar información'.";


$lang['dashboard']['help_sup1'] = "Para eliminar un valor permanetemente, haga clic en 'eliminar valor'.";
$lang['dashboard']['help_sup2'] = "Si desea unicamente deshabilitar un valor, cambie al estado 'borrador'.";
?>
